
#ifndef __RADIO_H
#define __RADIO_H

#pragma pack(push,2)

#include "BaseType.h"

#define MAX_SDU_DATASIZE 2048
#define MAX_QUEUED_SDUS  7
#define MESSAGE_RECEIVED    0x0601 // Radio Events
#define MESSAGE_SENT        0x0602
#define MESSAGE_NOT_SENT    0x0603
#define SIGNAL_LEVEL        0x0604
#define NETWORK_STARTED     0x0605
#define BASE_STATION_CHANGE 0x0606
#define RADIO_TURNED_OFF    0x0607
#define MESSAGE_STATUS      0x0608
#define SDU_NOT_SENT_TXKILL      245 // RADIO 'MESSAGE_NOT_SENT' error codes 
#define SDU_NOT_SENT             251
#define SDU_NOT_SENT_COVER       252
#define SDU_NOT_SENT_CANCEL      253
#define SDU_NOT_SENT_NO_RESPONSE 254
#define SDU_NOT_SENT_NO_ACK      255
#define SDU_NOT_SENT_HOST_DOWN   256
#define SDU_NOT_SENT_NOT_REG     257
#define SDU_NOT_SENT_BUSY        258
#define SDU_TX_PENDING   1 // RADIO 'MESSAGE_STATUS' codes
#define SDU_TRANSMITTING 2
#define RADIO_APP_NOT_REGISTERED -1 // RADIO function return error codes
#define RADIO_SDU_NOT_FOUND      -2
#define RADIO_NO_FREE_BUFFERS    -3
#define RADIO_BAD_DATA           -4
#define RADIO_BAD_TAG            -5
#define RADIO_ERROR_GENERAL      -6
#define RSSI_NO_COVERAGE -256 // RadioGetSignalLevel() special value
#define RADIO_OFF       0 // RadioOnOff() modes
#define RADIO_ON        1
#define RADIO_LOWBATT   2
#define RADIO_GET_ONOFF 3
#define SEND_NEW    0 // SDU resend values
#define SEND_RESEND 1
#define PRI_NORMAL   0 // SDU priority values
#define PRI_VERY_LOW 1
#define PRI_LOW      2
#define PRI_HIGH     3
#define RADIO_EXPRESS         0 // RadioChangePowerSave() modes
#define RADIO_PWRSAVE_MAXIMUM 1
#define RADIO_PWRSAVE_AVERAGE 2
#define RADIO_PWRSAVE_MINIMUM 3

typedef struct {
 WORD HeaderLength;
 BYTE Resend;
 BYTE Priority;
} SDU_HEADER;

typedef struct {
 SDWORD RadioOn;             // RADIO_ON, RADIO_OFF
 DWORD LLI;                  // The modem's LLI
 DWORD ESN;                  // The public ESN
 DWORD FaultBits;
 SDWORD RSSI;                // RSSI_NO_COVERAGE, -113 to -40
 BYTE  Area;                 // DataTAC network Area ID
 BYTE  Base;                 // DataTAC network Base ID
 WORD  ChannelDesignator;    // Current channel designator
 BYTE  ChannelAttributes[2]; // Current channel attributes
 WORD  RfVersion;            // Current rf protocol version number
 WORD  RcVersion;            // Current radio code version number
 BYTE  Reserved[2];
 BOOL  Contact;              // 1 = In range, 0 = out of range.
 DWORD PowerSaveMode;        // see power save modes below.
 BOOL  ReceiverEnabled;      // 1 = Rx enabled, 0 = Rx disabled.
 BOOL  TransmitterEnabled;   // 1 = Tx enabled, 0 = Tx disabled.
} RADIO_INFO;

typedef struct {
 int DefaultNetworkIndex; // Indicates which network is the default network
 int CurrentNetworkIndex; // Indicates which network is the current network
 int NumValidNetworks;    // Indicates number of valid networks.
 struct {
  BYTE NetworkName[10];   // Network name.
  BYTE NetworkAddress[3]; // Network home address.
  BYTE NetworkType;       // Network type (0 - DataTAC 4000, 1 - 5000, 2 - 6000).
  BYTE NetworkChannels;   // Number of channels for network.
  BYTE NetworkLLIs;       // Number of group LLIs for network.
 } Networks[10];
} NETWORKS_INFO;

int  __cdecl RadioCancelSendSdu( int sduTag );
int  __cdecl RadioChangePowerSave( int mode );
BOOL __cdecl RadioChangeNetworks( BYTE *networkName );
int  __cdecl RadioGetSdu( int sduTag, SDU_HEADER *header, BYTE *data );
int  __cdecl RadioSendSdu( SDU_HEADER *header, BYTE *data, int length );
void __cdecl RadioAccelerateRetries( int sduTag );
void __cdecl RadioDeregister( void );
void __cdecl RadioGetAvailableNetworks( NETWORKS_INFO *info );
void __cdecl RadioGetDetailedInfo( RADIO_INFO *info );
int  __cdecl RadioGetSignalLevel( void );
int  __cdecl RadioOnOff( int mode );
void __cdecl RadioRegister( void );
void __cdecl RadioResumeReception( void );
void __cdecl RadioStopReception( int sduTag );

#pragma pack(pop)

#endif  // __RADIO_H
