
#ifndef __FILESYS_H
#define __FILESYS_H

#include "BaseType.h"

#define DB_OK               0
#define DB_NO_DB           -1
#define DB_NO_REC          -2
#define DB_ERR_NO_SPACE    -10
#define DB_ERR_NO_HANDLE   -11
#define DB_ERR_NOT_EXIST   -12
#define DB_ERR_BAD_HANDLE  -13
#define DB_ERR_BAD_SIZE    -14
#define DB_ERR_BOUNDS      -15
#define DB_ERR_WRONG_DB    -16
#define DB_ERR_NOT_DIR     -17
#define DB_ERR_IS_DIR      -18
#define DB_ERR_NOT_ORPHAN  -19
#define DB_ERR_BAD_NAME    -20
#define DB_ERR_PRIV_HANDLE -21
#define DB_ERR_FILE_OPEN   -100
#define DB_ERR_NO_FILE     -101
#define DB_ERR_BAD_FILE    -102
#define DB_ERR_FILE_CLOSED -103

typedef char FileType;
typedef short HandleType;

#if 0
typedef int STATUS;
#endif

typedef enum {NORMAL, ORPHAN, DB_NAME} RecKind;

typedef struct {
 void *Disk;
 unsigned NumOfBlock;
 unsigned BlockSize;
 unsigned NumOfClean;
} FileSysInfoType;

typedef struct {
 unsigned Pos;
 unsigned Length;
 HandleType Db;
} FileInfoType;

FileType    __cdecl DbFileOpen(HandleType db, unsigned newRecSize);
STATUS      __cdecl DbFileClose(FileType file, BOOL trim);
STATUS      __cdecl DbDelete(char *fileName);
void        __cdecl DbFileSysInfo(FileSysInfoType *FileSysInfo);
HandleType  __cdecl DbFindNext(HandleType db, char *pattern);
HandleType  __cdecl DbGetHandle(char *fileName);
char       *__cdecl DbName(HandleType db);
void      **__cdecl DbPointTable();
DWORD       __cdecl DbPointTableEdition();
void        __cdecl DbMaxHandles(int *MaxRecHandles, int *MaxFileHandles);
STATUS      __cdecl DbAddOrphan(HandleType db, HandleType orphan);
HandleType  __cdecl DbAddRec(HandleType db, unsigned size, const void *data);
STATUS      __cdecl DbAndRec(HandleType rec, const void *mask, unsigned size, unsigned offSet);
STATUS      __cdecl DbDeleteRec(HandleType db, HandleType rec);
HandleType  __cdecl DbFirstRec(HandleType db);
unsigned    __cdecl DbFreeRec();
unsigned    __cdecl DbFreeSpace();
unsigned    __cdecl DbMaxNewRecSize(RecKind NewRec);
HandleType  __cdecl DbNextRec(HandleType prevRec);
int         __cdecl DbRecSize(HandleType rec, BOOL dataOnly);
STATUS      __cdecl DbReplaceOrphan(HandleType rec, HandleType orphan);
STATUS      __cdecl DbReplaceRec(HandleType rec, unsigned newSize, const void *data);
void        __cdecl DbSecure();
int         __cdecl DbSize(HandleType db, BOOL dataOnly);
BOOL        __cdecl DbFileInfo(FileType file, FileInfoType *fileInfo);
int         __cdecl DbFileRead(FileType file, void *data, unsigned size);
STATUS      __cdecl DbFileSeek(FileType file, unsigned pos);
STATUS      __cdecl DbFileWrite(FileType file, const void *data, unsigned size);
BOOL        __cdecl ValidHandle(HandleType Handle, const void *const *PointTable);
/* 29 not incl ValidHandle
DbAddOrphan
DbAddRec
DbAndRec
* DbCleanOneSector (2.5)
DbDelete
DbDeleteRec
DbFileClose
DbFileInfo
DbFileOpen
DbFileRead
DbFileSeek
DbFileSysInfo
DbFileWrite
DbFindNext
DbFirstRec
DbFreeRec
DbFreeSpace
DbGetHandle
DbMaxHandles
DbMaxNewRecSize
DbName
DbNextRec
DbPointTable
DbPointTableEdition
DbRecSize
DbReplaceOrphan
DbReplaceRec
DbSecure
DbSize
*/
#define HandleToPoint(Handle,PointTable) PointTable[Handle]

#endif // __FILESYS_H
