
#ifndef __LCD_API_H
#define __LCD_API_H

#pragma pack(push,2)

#include "BaseType.h"

#define LCD_MAXCONTRAST        31

#define LCD_OK                 0
#define LCD_BAD_HANDLE        -1
#define LCD_OUT_OF_MEMORY     -2
#define LCD_BAD_FONT_INDEX    -3

#define WHITE                  0
#define INVERT_OF_SRC_OR_DEST  1
#define INVERT_SRC_AND_DEST    2
#define COPY_INVERT_SRC        3
#define SRC_AND_INVERT_DEST    4
#define INVERT_DEST            5
#define SRC_XOR_DEST           6
#define INVERT_OF_SRC_AND_DEST 7
#define SRC_AND_DEST           8
#define INVERT_OF_SRC_XOR_DEST 9
#define NO_OP                  10
#define INVERT_SRC_OR_DEST     11
#define COPY_SRC               12
#define SRC_OR_INVERT_DEST     13
#define SRC_OR_DEST            14
#define BLACK                  15

#define DRAW_WHITE             0
#define DRAW_INVERT            1
#define DRAW_BLACK             2

#define FONT_8_PIXEL           0
#define FONT_10_PIXEL          1
#define FONT_USER              2
#define FONT_SET_MAX           5
#define FONT_REGULAR           FONT_8_PIXEL

#define TEXT_NORMAL            0
#define TEXT_UNDERLINE         1
#define TEXT_INVERT            2
#define TEXT_BLANK             4
#define TEXT_OVERSTRIKE        16

#define LCD_LEFT_JUSTIFIED     0
#define LCD_RIGHT_JUSTIFIED    32
#define LCD_CENTERED           64
#define LCD_MULTILINE          128
#define LCD_WORD_WRAP          256
#define LCD_ELLIPSIS           512
#define LCD_RAW                1024

#define CHAR_ELLIPSIS          0x1f

#define SYSTEM_MODAL_DC        1

#define BITMAP_TYPE_MONO       0

#define LCD_FONT_PROPORTIONAL  0x01
#define LCD_ADD_BLANK_COLUMN   0x80

typedef struct {
 BYTE bFontType;
 BYTE bFirstChar;
 BYTE bLastChar;
 BYTE bCharHeight;
 BYTE bCharUnderlineRow;
 BYTE bCharWidth;
 BYTE *bCharDefinitions;
 WORD *wCharOffsets;
} FontDefinition;

typedef struct {
 WORD LcdType;
 WORD contrastRange;
 WORD width, height;
} LcdConfig;

void __cdecl LcdGetConfig(LcdConfig *config);
void __cdecl LcdClearDisplay(void);
int  __cdecl LcdGetContrast(void);
void __cdecl LcdSetContrast(int contrast);
void __cdecl LcdForceRefresh(void);
void __cdecl LcdIconsEnable(BOOL IconsOn);
void __cdecl LcdCopyBitmapToDisplay(const BitMap * pbmSource, int iDisplayX, int iDisplayY);
void __cdecl LcdDrawLine(int iDrawingMode, int x1, int y1, int x2, int y2);
void __cdecl LcdDrawBox(int iDrawingMode, int x1, int y1, int x2, int y2);
void __cdecl LcdRasterOp(DWORD wOp, DWORD wWide, DWORD wHigh, const BitMap *src, int SrcX, int SrcY, BitMap *dest, int DestX, int DestY);
void __cdecl LcdSetPixel(int x, int y, BOOL value);
BOOL __cdecl LcdGetPixel(int x, int y);
void __cdecl LcdSetRegion(int left, int top, int width, int height, void *BitArray);
void __cdecl LcdGetRegion(int left, int top, int width, int height, void *BitArray);
int  __cdecl LcdCopyDisplay(int iSourceDC, int iDestDC);
int  __cdecl LcdSetDisplayContext(int iDC);
int  __cdecl LcdGetDisplayContext(void);
int  __cdecl LcdCreateDisplayContext(int iDisplayToCopy);
int  __cdecl LcdDestroyDisplayContext(int iDC);
void __cdecl LcdClearToEndOfLine(void);
int  __cdecl LcdGetCharacterWidth(char c, int iFontIndex);
int  __cdecl LcdGetCurrentFont(void);
void __cdecl LcdGetCursorPoint(int *xPixel, int *yPixel);
int  __cdecl LcdGetFontHeight(int iFontIndex);
int  __cdecl LcdGetStringWidth(const char *sz, int iFontIndex, int length);
int  __cdecl LcdPutStringXY(int x, int y, const char *s, int length, int flags);
int  __cdecl LcdReplaceFont(int iFontIndex, const FontDefinition *pNewFont);
int  __cdecl LcdSetCurrentFont(int iFontIndex);
void __cdecl LcdSetTextWindow(int x, int y, int wide, int high);
void __cdecl LcdScroll(int pixels);
int  __cdecl LcdGetNumberOfFonts(void);
int  __cdecl LcdGetFontName(int iFontIndex, const char **fontName);
/* 34
LcdClearDisplay
LcdClearToEndOfLine
LcdCopyBitmapToDisplay
LcdCopyDisplay
LcdCreateDisplayContext
LcdDestroyDisplayContext
* LcdDisplayHourglass (2.5)  LcdDisplayHourglass(TRUE) LcdDisplayHourglass(FALSE)  Works!
LcdDrawBox
LcdDrawLine
LcdForceRefresh
LcdGetCharacterWidth
LcdGetConfig
LcdGetContrast
LcdGetCurrentFont
LcdGetCursorPoint
LcdGetDisplayContext
LcdGetFontHeight
LcdGetFontName
LcdGetNumberOfFonts
LcdGetPixel
LcdGetRegion
LcdGetStringWidth
LcdIconsEnable
* LcdOnOff (2.5)  LcdOnOff(ON) LcdOnOff(OFF)  Works!
LcdPutStringXY
LcdRasterOp
LcdReplaceFont
LcdScroll
LcdSetContrast
LcdSetCurrentFont
LcdSetDisplayContext
LcdSetPixel
LcdSetRegion
LcdSetTextWindow */

#define LcdPutString(s,length,flags) LcdPutStringXY(-1, -1, s, length, flags)
#define LcdSetCursorPoint(xPixel,yPixel) LcdPutStringXY(xPixel, yPixel, "", 0, 0)

#pragma pack(pop)

#endif // __LCD_API_H
