
#ifndef __RIM_H
#define __RIM_H

#pragma pack(push,2)

#include "BaseType.h"

#define DEVICE_SYSTEM  1
#define DEVICE_KEYPAD  2
#define DEVICE_RTC     3
#define DEVICE_TIMER   4
#define DEVICE_COM1    5
#define DEVICE_RADIO   6
#define DEVICE_HOLSTER 7 

#define DEVICE_USER 128 

#define LAST_DEVICE DEVICE_HOLSTER

#define SWITCH_FOREGROUND 0x0100 
#define SWITCH_BACKGROUND 0x0101
#define BATTERY_LOW       0x0102
#define POWER_OFF         0x0103
#define POWER_UP          0x0104
#define TASK_LIST_CHANGED 0x0106
#define BATTERY_GOOD      0x0107
#define MEMORY_LOW        0x0108
#define BATTERY_UPDATE    0x0109
#define EVENT_USER        0x8000
#define RTC_CLOCK_UPDATE  0x0301
#define OUT_OF_HOLSTER    0x0700
#define IN_HOLSTER        0x0701
#define TIMER_PERIODIC 1
#define TIMER_ONE_SHOT 2
#define TIMER_ABSOLUTE 3
#define TICKS_PER_SECOND 100

#define TASK_NOT_FOUND ((TASK)0xffffffff)

#define NO_NOTIFY          0x00
#define TONE_ALERT         0x01
#define VIBRATE_ALERT      0x02
#define VIBRATE_AND_TONE   0x03
#define VIBRATE_THEN_TONE  0x04
#define PULSE_VIBRATE      0x00
#define CONTINUOUS_VIBRATE 0x01

#define KILL_NOTIFY -1
#define NO_NOTIFY    0

enum { TONE_SEQUENCE_1 = 1, TONE_SEQUENCE_2, TONE_SEQUENCE_3, 
TONE_SEQUENCE_4, TONE_SEQUENCE_5, TONE_SEQUENCE_6, TONE_SEQUENCE_UNUSED 
};

#define TUNE_SET_MAX (TONE_SEQUENCE_UNUSED - 1)

#define TUNE_OK         0
#define BAD_TUNE_INDEX -1

#define MC_DEVICE    0x01
#define MC_EVENT     0x02
#define MC_SUBMSG    0x04
#define MC_MASK_TAIL 0x08

#define DEV_PAGER    1
#define DEV_OEM      2
#define DEV_HANDHELD 3

#define NET_MOBITEX 1
#define NET_DATATAC 2

#define BSTAT_DEAD       0x80000000
#define BSTAT_TOO_COLD   0x40000000
#define BSTAT_TOO_HOT    0x20000000
#define BSTAT_LOW        0x10000000
#define BSTAT_NONE       0x00800000
#define BSTAT_REVERSED   0x00400000
#define BSTAT_NO_TURN_ON 0x00008000
#define BSTAT_NO_RADIO   0x00004000
#define BSTAT_CHARGING   0x00000001

typedef struct {
 DWORD Device;
 DWORD Event;
 DWORD SubMsg;
 DWORD Length;
 char *DataPtr;
 DWORD Data[2];
} MESSAGE;

typedef struct 
{
 BYTE second;
 BYTE minute;
 BYTE hour;
 BYTE date;
 BYTE month;
 BYTE day;
 WORD year;
 BYTE TimeZone;
} TIME;

typedef struct {
 const char *Name;
 BOOL EnableForeground;
 const BitMap *Icon;
} PID;

typedef struct {
 BYTE duty;
 BYTE volume;
 BYTE maxVolume;
 BYTE repetitions;
 BYTE vibrateTime;
 BYTE vibrateType;
 BYTE inHolsterNotify;
 BYTE outOfHolsterNotify;
 BYTE pause;
} AlertConfiguration;

typedef struct {
 BYTE deviceType;
 BYTE networkType;
 WORD reserved1;
 union {
  DWORD MAN;
  DWORD LLI;
  BYTE reserved2[16];
  } deviceId;
   DWORD ESN;
   BYTE HSN[16];
   BYTE reserved3[24];
} DEVICE_INFO;

typedef struct {
 const char * const langName;
 const unsigned int intlLangId;
 const char * const langString[0];
} LANGUAGE_DEF;

typedef struct {
 const unsigned int VERSION;
 const unsigned int numLangs;
 const LANGUAGE_DEF * const langs[0];
} AVAILABLE_LANGUAGES;

#ifndef _VA_LIST_DEFINED
typedef char * va_list;
#define _VA_LIST_DEFINED
#endif

typedef int (__cdecl *CALLBACK_FUNC)(MESSAGE *);
// 64
TASK  __cdecl RimCreateThread(void (*Entry)(void), DWORD Stacksize);
BOOL  __cdecl RimDisableAppSwitch(void);
BOOL  __cdecl RimEnableAppSwitch(void);
TASK  __cdecl RimFindTask(const char *Prefix);
TASK  __cdecl RimGetCurrentTaskID(void);
TASK  __cdecl RimGetMessage(MESSAGE *Msg);
BOOL  __cdecl RimGetPID(TASK hTask, PID * Pid, const char **Subtitle);
TASK  __cdecl RimGetForegroundApp(void);
void  __cdecl RimInvokeTaskSwitcher(void);
BOOL  __cdecl RimPeekMessage(void);
void  __cdecl RimPostMessage(TASK HTask, const MESSAGE *Msg);
BOOL  __cdecl RimRegisterMessageCallback(DWORD MessageBits, DWORD MaskBits, CALLBACK_FUNC HandlerFunc);
BOOL  __cdecl RimReplyMessage(TASK HTask, const MESSAGE *Msg);
BOOL  __cdecl RimRequestForeground(TASK HTask);
BOOL  __cdecl RimSendMessage(TASK HTask, const MESSAGE *Msg);
BOOL  __cdecl RimSendSyncMessage(TASK HTask, const MESSAGE *Msg, MESSAGE *ReplyMsg);
void  __cdecl RimSetPID(const PID *Pid);
void  __cdecl RimSetReceiveFromDevice(DWORD Device, BOOL ReceiveFrom);
const char * __cdecl RimSetSubTitle(const char *NewTitle);
void  __cdecl RimTaskYield(void);
void  __cdecl RimTerminateThread(void);
void  __cdecl RimToggleMessageReceiving(BOOL ReceiveMessages);
TASK  __cdecl RimWaitForSpecificMessage(MESSAGE *Msg, const MESSAGE *Compare, DWORD Mask);
void  __cdecl RimFree(void *Block);
void* __cdecl RimMalloc(DWORD Size);
DWORD __cdecl RimMemoryRemaining(void);
void* __cdecl RimRealloc(void *Ptr, DWORD Size);
TASK  __cdecl RimGetAlarm(TIME *Time);
BOOL  __cdecl RimSetAlarmClock(TIME *Time, BOOL Enable);
void  __cdecl RimGetDateTime(TIME *Time);
long  __cdecl RimGetIdleTime(void);
long  __cdecl RimGetTicks(void);
void  __cdecl RimKillTimer(DWORD TimerID);
BOOL  __cdecl RimSetDate(const TIME *Time);
BOOL  __cdecl RimSetTime(const TIME *Time);
BOOL  __cdecl RimSetTimer(DWORD TimerID, DWORD Time, DWORD Type);
BOOL  __cdecl RimSleep(DWORD Ticks);
void  __cdecl RimAlertNotify(int Notify, int MaxRepetitions);
void  __cdecl RimGetAlertConfiguration(AlertConfiguration *AlertConfig);
void  __cdecl RimSetAlertConfiguration(const AlertConfiguration *AlertConfig);
void  __cdecl RimSpeakerBeep(int Frequency, int Duration, int Duty, int Volume);
void  __cdecl RimTestAlert(int notify, AlertConfiguration *TrialConfig);
unsigned int __cdecl RimGetNumberOfTunes(void);
int   __cdecl RimGetTuneName(unsigned int tuneIndex, const char **tuneName);
void  __cdecl RimCatastrophicFailure(const char *FailureMessage);
void  __cdecl RimDebugPrintf(const char *String, ...);
DWORD __cdecl RimGetBatteryLevel(void);
void  __cdecl RimGetDeviceInfo(DEVICE_INFO *Info);
int   __cdecl RimGetLanguage(void);
BOOL  __cdecl RimGetSetOfLanguages(AVAILABLE_LANGUAGES **LangList);
TASK  __cdecl RimGetMessageRaw(MESSAGE *Msg);
DWORD __cdecl RimGetOSversion(void);
int   __cdecl RimHolsterStatus(void);
void  __cdecl RimInitiateReset(void);
BOOL  __cdecl RimPassword(void *PasswordData, int Length);
int   __cdecl RimPagerSetup(int CallType, void *Pointer);
BOOL  __cdecl RimRequestPowerOff(void);
void  __cdecl RimSetLanguage(unsigned int Language);
int   __cdecl RimSprintf(char *Str, int Maxlen, const char *Fmt, ...);
DWORD __cdecl RimStackUsage(void);
int   __cdecl RimVsprintf(char *Buf, int Maxsize, const char *Fmt, va_list Argp);
BOOL  __cdecl RimRegisterForPowerDown(void);
void  __cdecl RimPowerDownHandled(void);
BOOL  __cdecl RimRequestStorageMode(void);
/* 76  - 12 new
RimAlertNotify
* RimCatastrophicAPIFailure (NEW)
RimCatastrophicFailure
* RimConfigureLEDs (NEW) in led.h
RimCreateThread
RimDebugPrintf
RimDisableAppSwitch
RimEnableAppSwitch
RimFindTask
* RimFlashSize (2.5)
RimFree
RimGetAlarm
RimGetAlertConfiguration
RimGetBatteryLevel
* RimGetBatteryStatus (2.5)
RimGetCurrentTaskID
RimGetDateTime
RimGetDeviceInfo
RimGetForegroundApp
RimGetIdleTime
RimGetLanguage
* RimGetLoadedAppInfo (2.5)
* RimGetMaxAllocSize (2.5)
RimGetMessage
RimGetMessageRaw
RimGetNumberOfTunes
RimGetOSversion
RimGetPID
* RimGetPasswordFailureCount (2.5)
RimGetSetOfLanguages
RimGetTicks
RimGetTuneName
RimHolsterStatus
RimInitiateReset
RimInvokeTaskSwitcher
RimKillTimer
RimMalloc
RimMemoryRemaining
RimPagerSetup
RimPassword
RimPeekMessage
RimPostMessage
RimPowerDownHandled
* RimPriorityMessageCount  (2.5)
RimRealloc
RimRegisterForPowerDown
RimRegisterMessageCallback
RimReplyMessage
RimRequestForeground
* RimRequestFullPowerOff (2.5)
RimRequestPowerOff
RimRequestStorageMode
RimSendMessage
RimSendSyncMessage
RimSetAlarmClock
RimSetAlertConfiguration
RimSetDate
RimSetLanguage
* RimSetLed (NEW) in led.h
RimSetPID
* RimSetPassword (2.5)
RimSetReceiveFromDevice
RimSetSubTitle
RimSetTime
RimSetTimer
RimSleep
RimSpeakerBeep
RimSprintf
RimStackUsage
RimTaskYield
RimTerminateThread
RimTestAlert
RimToggleMessageReceiving
* RimVerifyPassword (2.5)
RimVsprintf
RimWaitForSpecificMessage
*/
#pragma pack(pop)

#endif // __RIM_H
