
#ifndef __SERIAL_H
#define __SERIAL_H

#include "BaseType.h"

#define SERIAL_DTR_CHANGE     0x0501 // Serial Events
#define SERIAL_RX_ERROR       0x0502
#define SERIAL_RX_AVAILABLE   0x0503
#define SERIAL_TX_EMPTY       0x0504
#define SERIAL_RTS_CHANGE     0x0505
#define SERIAL_PATTERN_NOTIFY 0x0506
#define SERIAL_DCD_CHANGE     0x0507
#define SERIAL_NO_PARITY      0
#define SERIAL_EVEN_PARITY    1
#define SERIAL_ODD_PARITY     2

typedef enum FlowControlType {
 SERIAL_NO_FLOW_CONTROL,
 SERIAL_SOFTWARE_FLOW_CONTROL,
 SERIAL_RTS_CTS_FLOW_CONTROL,
} FlowControlType;

#define SERIAL_ERROR_NOT_OPEN -1
#define SERIAL_ERROR_PARITY    2
#define SERIAL_ERROR_FRAMING   3
#define SERIAL_ERROR_OVERRUN   4
#define SERIAL_ERROR_BREAK     5

extern int SerialSuspendPrevent;

typedef struct SerialOpenParms {
 DWORD baud;                // default 9600
 int   databits;            // default 8
 int   parity;              // default SERIAL_NO_PARITY
 int   stopbits;            // default 1
 DWORD RxBufferSize;        // default 1024
 DWORD TxBufferSize;        // default 1024
 enum FlowControlType flow; // default SERIAL_NO_FLOW_CONTROL
} SerialOpenParms;

BOOL __cdecl SerialOpen( unsigned port, const struct SerialOpenParms *parms, DWORD SizeofParms );
BOOL __cdecl SerialSettings( unsigned port, DWORD baud, int databits, int parity, int stopbits );
void __cdecl SerialSetFlowControl( unsigned port, enum FlowControlType flow );
void __cdecl SerialClose( unsigned port );
int  __cdecl SerialRead( unsigned port, BYTE *data, int length );
int  __cdecl SerialReadChar( unsigned port );
int  __cdecl SerialSend( unsigned port, const BYTE *data, int length );
int  __cdecl SerialSendChar( unsigned port, BYTE character );
BOOL __cdecl SerialGetDTR( unsigned port );
void __cdecl SerialSetDSR( unsigned port, BOOL state );
BOOL __cdecl SerialGetRTS( unsigned port );
void __cdecl SerialSetCTS( unsigned port, BOOL state );
void __cdecl SerialSetRI( unsigned port, BOOL state );
BOOL __cdecl SerialGetDCD( unsigned port );
void __cdecl SerialStandby( unsigned port, BOOL state );
int  __cdecl SerialRxCount( unsigned port );
int  __cdecl SerialTxCount( unsigned port );
void __cdecl SerialRxFlush( unsigned port );
void __cdecl SerialTxFlush( unsigned port );

#endif // __SERIAL_H
