
#ifndef __RADIO_H
#define __RADIO_H

#pragma pack(push,2)

#include "BaseType.h"

#define MAX_QUEUED_MPAKS 7

#define MESSAGE_RECEIVED    0x0601
#define MESSAGE_SENT        0x0602
#define MESSAGE_NOT_SENT    0x0603
#define SIGNAL_LEVEL        0x0604
#define NETWORK_STARTED     0x0605
#define BASE_STATION_CHANGE 0x0606
#define RADIO_TURNED_OFF    0x0607
#define MESSAGE_STATUS      0x0608

#define MPAK_NOT_SENT_TXKILL        245
#define MPAK_NOT_SENT               251
#define MPAK_NOT_SENT_COVER         252
#define MPAK_NOT_SENT_CANCEL        253
#define MPAK_INCORRECT              255
#define MPAK_INCORRECT_TYPE         256
#define MPAK_INCORRECT_STATE        257
#define MPAK_INCORRECT_FLAGS        258
#define MPAK_INCORRECT_SENDLIST     259
#define MPAK_INCORRECT_LENGTH       260
#define MPAK_INCORRECT_ADDRESSEE    261
#define MPAK_PERSONAL_MAN_EXIST     262
#define MPAK_PERSONAL_MAN_NOT_EXIST 263
#define MPAK_NOT_SENT_DIE           265
#define MPAK_NOT_SENT_BUFFER_FULL   266
#define MPAK_NOT_SENT_REDUNDANT     267
#define MPAK_TX_PENDING             1
#define MPAK_TRANSMITTING           2

#define RADIO_APP_NOT_REGISTERED -1
#define RADIO_MPAK_NOT_FOUND     -2
#define RADIO_NO_FREE_BUFFERS    -3
#define RADIO_BAD_DATA           -4
#define RADIO_BAD_TAG            -5
#define RADIO_ERROR_GENERAL      -6
#define RADIO_ILLEGAL_SKIPNUM    -7
#define RADIO_ILLEGAL_WSM_PACKET -8

#define RSSI_NO_COVERAGE -256

#define RADIO_OFF       0
#define RADIO_ON        1
#define RADIO_LOWBATT   2
#define RADIO_GET_ONOFF 3

#define TS_MESSAGE_OK           0
#define TS_MESSAGE_FROM_MAILBOX 1
#define TS_MESSAGE_IN_MAILBOX   2
#define TS_CANNOT_BE_REACHED    3
#define TS_ILLEGAL_MESSAGE      4
#define TS_NETWORK_CONGESTED    5
#define TS_TECHNICAL_ERROR      6
#define TS_DESTINATION_BUSY     7

#define FLAG_MAILBOX      1
#define FLAG_POSACK       2
#define FLAG_SENDLIST     4
#define FLAG_UNKNOWN_FLAG 8

#define MPAK_TEXT   1
#define MPAK_DATA   2
#define MPAK_STATUS 3
#define MPAK_HPDATA 4

#define MAX_MPAK_SIZE      560
#define MAX_MPAK_DATA_SIZE 512

#define PCLASS_PSUBCOM 0
#define PCLASS_DTESERV 3
#define PCLASS_PSOSCOM 1

#define MPAK_LOGINREQ  1
#define MPAK_LOGINGRA  2
#define MPAK_LOGINREF  3
#define MPAK_LOGOUT    4
#define MPAK_LOGOUTORD 5
#define MPAK_ACTIVE    7
#define MPAK_INACTIVE  8
#define MPAK_VICESOSRX 13
#define MPAK_SOSRX     14
#define MPAK_GROUPLIST 15
#define MPAK_FLEXLIST  17
#define MPAK_TIME      20
#define MPAK_MODE      24

#define TRAFFIC_STATE_OFFSET 6
#define TRAFFIC_STATE_MASK   0xe0
#define TRAFFIC_STATE_SHIFT  5
#define TRAFFIC_STATE_OK     0

#define MAILBOX_FLAG_OFFSET 6
#define MAILBOX_FLAG_MASK   0x01
#define MAILBOX_FLAG_SHIFT  0

#define POSACK_FLAG_OFFSET 6
#define POSACK_FLAG_MASK   0x02
#define POSACK_FLAG_SHIFT  1

#define SENDLIST_FLAG_OFFSET 6
#define SENDLIST_FLAG_MASK   0x04
#define SENDLIST_FLAG_SHIFT  2

#define UNKNOWN_FLAG_OFFSET 6
#define UNKNOWN_FLAG_MASK   0x08
#define UNKNOWN_FLAG_SHIFT  3

#define PACKET_CLASS_OFFSET 7
#define PACKET_CLASS_MASK   0xc0
#define PACKET_CLASS_SHIFT  6

#define EXTERNAL_FLAG_OFFSET 7
#define EXTERNAL_FLAG_MASK   0x20
#define EXTERNAL_FLAG_SHIFT  5

#define PACKET_TYPE_OFFSET  7
#define PACKET_TYPE_MASK    0x1f
#define PACKET_TYPE_SHIFT   0

#define INDEPENDENT_HEADER_SIZE 8
#define TIMESTAMP_OFFSET        8
#define TIMESTAMP_LENGTH        3
#define DATA_OFFSET             11
#define SENDLIST_OFFSET         8
#define SENDLIST_LENGTH         22
#define HP_PROTOCOL_ID_OFFSET   11

typedef struct {
 long Sender;
 long Destination;
 int MpakType;
 int HPID;
 int Flags;
 TIME Timestamp;
 long lTime;
 int TrafficState;
} MPAK_HEADER;

typedef struct {
 int RadioOn;
 DWORD LocalMAN;
 DWORD ESN;
 int Base;
 int Area;
 int RSSI;
 WORD NetworkID;
 DWORD FaultBits;
 BOOL Active;
 BOOL PowerSaveMode;
 BOOL LiveState;
 BOOL TransmitterEnabled;
} RADIO_INFO;

typedef struct {
 BYTE SkipNum;
 BYTE ProtocolRevision;
 BYTE SkipTrans;
 BYTE Mode;
} SKIPNUM_INFO;

typedef struct {
 int DefaultNetworkIndex;
 int CurrentNetworkIndex;
 int NumValidNetworks;
 struct {
  WORD NetworkId;
  BYTE NetworkName[10];
 } Networks[10];
} NETWORKS_INFO;

void __cdecl RadioAccelerateRetries(int mpakTag);
int  __cdecl RadioCancelSendMpak(int mpakTag);
// void __cdecl RadioCancelSendSdu();
void __cdecl RadioChangeNetworks(DWORD NetworkId, BYTE *NetworkName);
// void __cdecl RadioChangeNetworksDataTAC();
// void __cdecl RadioChangeNetworksMobitex();
// void __cdecl RadioChangePowerSave();
void __cdecl RadioDeregister(void);
void __cdecl RadioGetAvailableNetworks(NETWORKS_INFO *info);
void __cdecl RadioGetDetailedInfo(RADIO_INFO *info);
int  __cdecl RadioGetMpak(int mpakTag, MPAK_HEADER *header, BYTE *data);
// void __cdecl RadioGetSdu();
int  __cdecl RadioGetSignalLevel(void);
int  __cdecl RadioOnOff(int mode);
void __cdecl RadioRegister(void);
int  __cdecl RadioRequestSkipnum(SKIPNUM_INFO *SkipInfo, int Skipnum);
void __cdecl RadioResumeReception(void);
void __cdecl RadioRoamNow(void);
int  __cdecl RadioSendMpak(MPAK_HEADER *header, BYTE *data, int length);
// void __cdecl RadioSendSdu();
// void __cdecl RadioSetup();
void __cdecl RadioStopReception(int mpakTag);

#pragma pack(pop)

#endif // __RADIO_H
