/****************************************************************************
 * File    : winapp.c                                                       *
 * Purpose : Windows GUI application wizard.                                *
 * MODIFIED FOR BLACKBERRY WIZARD                                           *
 ****************************************************************************/
#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <tchar.h>
#include <wizard.h>
#include "winapp.h"
#define NELEMS(a)  (sizeof(a) / sizeof(a[0]))

static int cchProjname;
static int cchDispname;
static TCHAR g_szProjname[9];
static TCHAR g_szPROJNAME[9];
static TCHAR g_szDispname[80];
static BOOL g_fSimple = FALSE;

static BOOL WINAPI OnStep1(HWND, enum WizAction); // Static function prototypes
static BOOL WINAPI OnStep2(HWND, enum WizAction);
static void WINAPI OnFileLine(PTSTR, int);

/****************************************************************************
 * Function: WizMain                                                        *
 * Purpose : Wizard entry point.                                            *
 ****************************************************************************/
BOOL WINAPI WizMain(void)
{
  TCHAR szTail[16];
  TCHAR szBuffer[1024];
  if(!WizGetProjectName(szBuffer, NELEMS(szBuffer))) // Get current project name
    return FALSE;
  // Build project names for the macro substitution
  cchProjname = lstrlen(lstrcpyn(g_szProjname, szBuffer, NELEMS(g_szProjname)));
  CharUpper(lstrcpy(g_szPROJNAME, g_szProjname)); // Create UPPERCASE name
  // Build a default display name
  LoadString(WizGetInstanceHandle(), IDS_APPLICATION, szTail, NELEMS(szTail));
  lstrcpyn(g_szDispname, szBuffer, NELEMS(g_szDispname) - lstrlen(szTail));
  lstrcat(g_szDispname, szTail); // <program name> name
  // Add the dialog pages for this wizard
  if(!WizAddStep(MAKEINTRESOURCE(DLG_START), OnStep1)
    ||!WizAddStep(MAKEINTRESOURCE(DLG_FINISH), OnStep2))
    return FALSE;
  if(!WizShowSteps()) // Let the user interact with the wizard
    return FALSE;
  if(!WizSetProjectType(Project_Win32_DLL)) // Set project type (.DLL)
    return FALSE;
  // Write the source file with macro substitution in OnFileLine().
  cchDispname = lstrlen(g_szDispname);
/*  if(!WizWriteTextFileFromResourceA("main.c",MAKEINTRESOURCE(IDR_MAIN_C),OnFileLine)
    ||!WizWriteTextFileFromResourceA("icon.h",MAKEINTRESOURCE(IDR_MAIN_H),OnFileLine)
    ||!WizWriteFileFromResourceA("OSEntry.obj",MAKEINTRESOURCE(IDR_MAIN_RC)))
    return FALSE;*/
  WizWriteFileFromResourceA("OSEntry.obj",MAKEINTRESOURCE(IDR_MAIN_RC));
  if(g_fSimple)
    WizWriteTextFileFromResourceA("main.c",MAKEINTRESOURCE(8006),OnFileLine);
  else
  {
    WizWriteTextFileFromResourceA("main.c",MAKEINTRESOURCE(IDR_MAIN_C),OnFileLine);
    WizWriteTextFileFromResourceA("icon.h",MAKEINTRESOURCE(IDR_MAIN_H),OnFileLine);
  }
  // Add the *source* files to the project. WizAddProjectFile() will only
  // accept .C and .RC files. Any files referenced from these files
  // (like .H, .ICO, ...) will be added automatically by the IDE).
  if(!WizAddProjectFile("main.c")) return FALSE;
  // Add special BlackBerry compiler and linker flags
  if(g_fSimple) // TRUE (simple)
  {
    if(!WizSetProjectSymbol("LINKFLAGS",
    "-subsystem:windows -machine:ix86 -DLL /EXPORT:RimHeader OSEntry.obj rimos.lib"))
      return FALSE;
  }
  else
  {
    if(!WizSetProjectSymbol("LINKFLAGS",
    "-subsystem:windows -machine:ix86 -DLL /EXPORT:RimHeader OSEntry.obj rimos.lib ribbon.lib"))
      return FALSE;
  }
  if(!WizSetProjectSymbol("CCFLAGS"," -Tx86-coff -Os -W1 -Gd -Ze"))
    return FALSE;
  return TRUE;
}

/****************************************************************************
 * Function: OnStep1                                                        *
 * Purpose : Handle events for step page #1.                                *
 ****************************************************************************/
static BOOL WINAPI OnStep1(HWND hwnd, enum WizAction action)
{
  switch (action)
  {
    case Action_SetActive: // Set the display name
      SetDlgItemText(hwnd, DID_DISPNAME, g_szDispname); // Set the program type
      CheckRadioButton(hwnd, DID_SIMPLE, DID_HELLO, g_fSimple ? DID_SIMPLE : DID_HELLO);
      return TRUE;
    case Action_KillActive:
      // Remember the display name
      GetDlgItemText(hwnd, DID_DISPNAME, g_szDispname, NELEMS(g_szDispname));
      g_fSimple = IsDlgButtonChecked(hwnd, DID_SIMPLE); // Remember the program type
      return g_szDispname[0] != '\0';
  }
  return FALSE;
}

/****************************************************************************
 * Function: OnStep2                                                        *
 * Purpose : Handle events for step page #2.                                *
 ****************************************************************************/
static BOOL WINAPI OnStep2(HWND hwnd, enum WizAction action)
{
  switch (action)
  {
    case Action_SetActive:
    {
      TCHAR szProjPath[260]; // TODO - CHANGE SO 2 VERSIONS ARE IN RESOURCE
      SendDlgItemMessage(hwnd,DID_RESULTFILES,LB_RESETCONTENT,0,0); // Fill Listbox
      SendDlgItemMessage(hwnd,DID_RESULTFILES,LB_ADDSTRING,0,(LPARAM)(LPSTR)"main.c");
      if(g_fSimple==FALSE)
        SendDlgItemMessage(hwnd,DID_RESULTFILES,LB_ADDSTRING,0,(LPARAM)(LPSTR)"icon.h");
      SendDlgItemMessage(hwnd,DID_RESULTFILES,LB_ADDSTRING,0,(LPARAM)(LPSTR)"OSEntry.obj");
      GetCurrentDirectory(NELEMS(szProjPath), szProjPath);
      SetDlgItemText(hwnd, DID_PROJFOLDER, szProjPath); // Display project path
      return TRUE;
    }
    case Action_KillActive:
      return TRUE;
  }
  return FALSE;
}

/****************************************************************************
 * Function: OnFileLine                                                     *
 * Purpose : Perform simple macro substitution for the source files.        *
 ****************************************************************************/
static void WINAPI OnFileLine(PTSTR pszLine,int cchMaxLine) // Norm 4096 chars
{
  PTSTR psz;
  for (;;)
  {
    if((psz = _tcsstr(pszLine, TEXT("<Projname>"))) != NULL) // String search
    {
      int cchLine = lstrlen(pszLine);
      _tmemmove(psz + cchProjname, psz+10, pszLine + cchLine - (psz+10)+1);
      _tmemcpy(psz, g_szProjname, cchProjname);
    }
    else if((psz = _tcsstr(pszLine, TEXT("<PROJNAME>"))) != NULL)
    {
      int cchLine = lstrlen(pszLine);
      _tmemmove(psz + cchProjname, psz+10, pszLine + cchLine - (psz+10)+1);
      _tmemcpy(psz, g_szPROJNAME, cchProjname);
    }
    else if((psz = _tcsstr(pszLine, TEXT("<Dispname>"))) != NULL)
    {
      int cchLine = lstrlen(pszLine);
      _tmemmove(psz + cchDispname, psz+10, pszLine + cchLine - (psz+10)+1);
      _tmemcpy(psz, g_szDispname, cchDispname);
    }
    else
      break;
  }
}
